==> sunny-foundation-0.2.25.tgz: package/Auth/channel.ts <==
import { ReplaySubject } from 'rxjs'
import { bindOn, createAction } from 'sunny-js/util/Channel'
export * from 'sunny-js/util/Channel'

/**
 * 创建一个用于处理认证事件的广播
 * 使用ReplaySubject创建频道，bufferSize 1 表示总是可以让新的订阅者收到最后一个事件
 *
 * 使用ReplaySubject创建频道，可以让订阅者相关逻辑懒加载。
 * 表示订阅者可以在事件发生后订阅频道并能够收到最后一个事件
 */
const authChannel = new ReplaySubject(1)
export const on = bindOn(authChannel)

export function sendAction (action) {
  return authChannel.next(action)
}

/**
 * 请求 登录 事件
 * @deprecated
 */
export const LOGIN = requestLogin.name

/**
 * @deprecated
 */
export function createLoginAction (payload) {
  return createAction(requestLogin.name, payload)
}

/**
 * @deprecated
 */
export const LOGIN_SUCCESS = loginSuccess.name

/**
 * @deprecated
 */
export function createLoginSuccessAction (payload) {
  return createAction(loginSuccess.name, payload)
}

/**
 * 发送登录成功事件
 */
export function loginSuccess (payload?) {
  return sendAction(createAction(loginSuccess.name, payload))
}
/**
 * 监听登录成功事件
 * 该方法如果不注销unsubscribe，会常驻内存，持续监听
 * @param {function} callback 收到登录成功的事件后会调用callback
 * @param {string} [key] 可选，在使用Function.prototype.bind绑定的函数，要求传入
 * @example
 * // 开始监听
 * const subscription = onLoginSuccess((payload) => {})
 * // 注销监听
 * subscription.unsubscribe()
 */
export function onLoginSuccess (callback, key?) {
  return on(loginSuccess.name, callback, key)
}
// 发送用户退出事件
export function logout (payload?) {
  return sendAction(createAction(logout.name, payload))
}
// 监听用户退出事件
export function onLogout (callback, key?) {
  return on(logout.name, callback, key)
}

// 发送请求登录事件
export function requestLogin (payload?) {
  return sendAction(createAction(requestLogin.name, payload))
}
/**
 * 监听请求登录事件
 * 该方法如果不注销unsubscribe，会常驻内存，持续监听
 * @param {function} callback 收到请求登录的事件后会调用callback
 * @param {string} [key] 可选，在使用Function.prototype.bind绑定的函数，要求传入
 * @example
 * // 开始监听
 * const subscription = onRequestLogin((payload) => {})
 * // 注销监听
 * subscription.unsubscribe()
 */
export function onRequestLogin (callback, key?) {
  return on(requestLogin.name, callback, key)
}

/**
 * @deprecated
 */
export const BLOCK_VISITOR = blockVisitor.name
// 发送 无权访问 事件
export function blockVisitor (payload?) {
  return sendAction(createAction(blockVisitor.name, payload))
}
// 监听 当用户被阻止访问时的 事件
export function onBlocked (callback, key?) {
  return on(blockVisitor.name, callback, key)
}

export default authChannel

==> sunny-foundation-0.2.26.tgz: package/Auth/channel.ts <==
import { ReplaySubject } from 'rxjs'
import { bindOn, createAction } from 'sunny-js/util/Channel'
export * from 'sunny-js/util/Channel'

/**
 * 创建一个用于处理认证事件的广播
 * 使用ReplaySubject创建频道，bufferSize 1 表示总是可以让新的订阅者收到最后一个事件
 *
 * 使用ReplaySubject创建频道，可以让订阅者相关逻辑懒加载。
 * 表示订阅者可以在事件发生后订阅频道并能够收到最后一个事件
 */
const authChannel = new ReplaySubject(1)
export const on = bindOn(authChannel)

export function sendAction (action) {
  return authChannel.next(action)
}

/**
 * 请求 登录 事件
 * @deprecated
 */
export const LOGIN = requestLogin.name

/**
 * @deprecated
 */
export function createLoginAction (payload) {
  return createAction(requestLogin.name, payload)
}

/**
 * @deprecated
 */
export const LOGIN_SUCCESS = loginSuccess.name

/**
 * @deprecated
 */
export function createLoginSuccessAction (payload) {
  return createAction(loginSuccess.name, payload)
}

/**
 * 发送登录成功事件
 */
export function loginSuccess (payload?) {
  return sendAction(createAction(loginSuccess.name, payload))
}
/**
 * 监听登录成功事件
 * 该方法如果不注销unsubscribe，会常驻内存，持续监听
 * @param {function} callback 收到登录成功的事件后会调用callback
 * @param {string} [key] 可选，在使用Function.prototype.bind绑定的函数，要求传入
 * @example
 * // 开始监听
 * const subscription = onLoginSuccess((payload) => {})
 * // 注销监听
 * subscription.unsubscribe()
 */
export function onLoginSuccess (callback, key?) {
  return on(loginSuccess.name, callback, key || callback + onLoginSuccess.name)
}
// 发送用户退出事件
export function logout (payload?) {
  return sendAction(createAction(logout.name, payload))
}
// 监听用户退出事件
export function onLogout (callback, key?) {
  return on(logout.name, callback, key || callback + onLogout.name)
}

// 发送请求登录事件
export function requestLogin (payload?) {
  return sendAction(createAction(requestLogin.name, payload))
}
/**
 * 监听请求登录事件
 * 该方法如果不注销unsubscribe，会常驻内存，持续监听
 * @param {function} callback 收到请求登录的事件后会调用callback
 * @param {string} [key] 可选，在使用Function.prototype.bind绑定的函数，要求传入
 * @example
 * // 开始监听
 * const subscription = onRequestLogin((payload) => {})
 * // 注销监听
 * subscription.unsubscribe()
 */
export function onRequestLogin (callback, key?) {
  return on(requestLogin.name, callback, key || callback + onRequestLogin.name)
}

/**
 * @deprecated
 */
export const BLOCK_VISITOR = blockVisitor.name
// 发送 无权访问 事件
export function blockVisitor (payload?) {
  return sendAction(createAction(blockVisitor.name, payload))
}
// 监听 当用户被阻止访问时的 事件
export function onBlocked (callback, key?) {
  return on(blockVisitor.name, callback, key || callback + onBlocked.name)
}

export default authChannel
